@@ -2,9 +2,6 @@ import os
 import sys
 import threading
 
-from paste.script.templates import Template
-from paste.util.template import paste_script_template_renderer
-
 from zope.configuration.fields import GlobalInterface
 from zope.configuration.fields import GlobalObject
 from zope.configuration.fields import Tokens
@@ -873,11 +870,11 @@ def make_app(root_factory, package=None, filename='configure.zcml',
     """ Return a Router object, representing a fully configured
     Pyramid WSGI application.
 
-    .. warning:: Use of this function is deprecated as of
-       Pyramid 1.0.  You should instead use a
-       :class:`pyramid.config.Configurator` instance to
-       perform startup configuration as shown in
-       :ref:`configuration_narr`.
+    .. warning::
+
+       Use of this function is deprecated as of Pyramid 1.0.  You should
+       instead use a :class:`pyramid.config.Configurator` instance to perform
+       startup configuration as shown in :ref:`configuration_narr`.
 
     ``root_factory`` must be a callable that accepts a :term:`request`
     object and which returns a traversal root object.  The traversal
@@ -923,18 +920,6 @@ def make_app(root_factory, package=None, filename='configure.zcml',
     config.end()
     return config.make_wsgi_app()
 
-# paster template helper
-
-class PyramidTemplate(Template):
-    def pre(self, command, output_dir, vars): # pragma: no cover
-        vars['random_string'] = os.urandom(20).encode('hex')
-        return Template.pre(self, command, output_dir, vars)
-
-class StarterZCMLProjectTemplate(PyramidTemplate):
-    _template_dir = 'paster_templates/starter_zcml'
-    summary = 'pyramid starter project (using ZCML)'
-    template_renderer = staticmethod(paste_script_template_renderer)
-
 # includeme function for config.include'ability
 
 def includeme(config):
